@@ -35,12 +35,14 @@ static struct option long_opts[] = {
 #ifdef WITH_SELINUX
 	{ "selinux", required_argument, NULL, 's' },
 #endif
+	{ "xattr-file", required_argument, NULL, 'A' },
+	{ "sort-file", required_argument, NULL, 'S' },
 	{ "version", no_argument, NULL, 'V' },
 	{ "help", no_argument, NULL, 'h' },
 	{ NULL, 0, NULL, 0 },
 };
 
-static const char *short_opts = "F:D:X:c:b:B:d:u:g:j:Q:kxoefqThV"
+static const char *short_opts = "F:D:X:c:b:B:d:u:g:j:Q:S:A:kxoefqThV"
 #ifdef WITH_SELINUX
 "s:"
 #endif
@@ -53,7 +55,9 @@ static const char *help_string =
 "Usage: gensquashfs [OPTIONS...] <squashfs-file>\n"
 "\n"
 "Possible options:\n"
-"\n"
+"\n";
+
+static const char *pack_options =
 "  --pack-file, -F <file>      Use a `gen_init_cpio` style description file.\n"
 "                              The file format is specified below.\n"
 "                              If --pack-dir is used, input file paths are\n"
@@ -63,9 +67,8 @@ static const char *help_string =
 "  --pack-dir, -D <directory>  If --pack-file is used, this is the root path\n"
 "                              relative to which to read files. If no pack\n"
 "                              file is specified, pack the contents of the\n"
-"                              given directory into a SquashFS image. The\n"
-"                              directory becomes the root of the file\n"
-"                              system.\n"
+"                              given directory. The directory becomes the\n"
+"                              file system root.\n"
 "\n"
 "  --compressor, -c <name>     Select the compressor to use.\n"
 "                              A list of available compressors is below.\n"
@@ -97,11 +100,19 @@ static const char *help_string =
 "                              this value, no matter what the pack file or\n"
 "                              directory entries actually specify.\n"
 "  --all-root                  A short hand for `--set-uid 0 --set-gid 0`.\n"
+"\n";
+
+const char *extra_options =
+"  --sort-file, -S <file>      Specify a \"sort file\" that can be used to\n"
+"                              micro manage the order of files during packing\n"
+"                              and behaviour (compression, fragmentation, ..)\n"
 "\n"
 #ifdef WITH_SELINUX
 "  --selinux, -s <file>        Specify an SELinux label file to get context\n"
 "                              attributes from.\n"
 #endif
+"  --xattr-file, -A <file>     Specify an Xattr file to get extended attributes\n"
+"                              for loading xattrs\n"
 "  --keep-time, -k             When using --pack-dir only, use the timestamps\n"
 "                              from the input files instead of setting\n"
 "                              defaults on all input paths.\n"
@@ -118,40 +129,17 @@ static const char *help_string =
 "  --version, -V               Print version information and exit.\n"
 "\n";
 
-const char *help_details =
-"When using the pack file option, the given file is expected to contain\n"
-"newline separated entries that describe the files to be included in the\n"
-"SquashFS image. The following entry types can be specified:\n"
+const char *pack_details =
+"Example of a pack file:\n"
 "\n"
-"# a comment\n"
-"file <path> <mode> <uid> <gid> [<location>]\n"
-"dir <path> <mode> <uid> <gid>\n"
-"nod <path> <mode> <uid> <gid> <dev_type> <maj> <min>\n"
-"slink <path> <mode> <uid> <gid> <target>\n"
-"link <path> <dummy> <dummy> <dummy> <target>\n"
-"pipe <path> <mode> <uid> <gid>\n"
-"sock <path> <mode> <uid> <gid>\n"
-"glob <path> <mode|*> <uid|*> <gid|*> [OPTIONS...] <location>\n"
-"\n"
-"<path>       Absolute path of the entry in the image. Can be put in quotes\n"
-"             if some components contain spaces.\n"
-"<location>   If given, location of the input file. Either absolute or relative\n"
-"             to the description file. If omitted, the image path is used,\n"
-"             relative to the description file.\n"
-"<target>     Symlink or hardlink target.\n"
-"<mode>       Mode/permissions of the entry.\n"
-"<uid>        Numeric user id.\n"
-"<gid>        Numeric group id.\n"
-"<dev_type>   Device type (b=block, c=character).\n"
-"<maj>        Major number of a device special file.\n"
-"<min>        Minor number of a device special file.\n"
-"\n"
-"Example:\n"
 "    # A simple squashfs image\n"
 "    dir /dev 0755 0 0\n"
 "    nod /dev/console 0600 0 0 c 5 1\n"
 "    dir /root 0700 0 0\n"
-"    dir /sbin 0755 0 0\n"
+"    \n"
+"    # `slink` for symlink, `link` for hard links\n"
+"    slink /lib 0777 0 0 /usr/lib\n"
+"    link /init 0777 0 0 /sbin/init\n"
 "    \n"
 "    # Add a file. Input is relative to listing or pack dir.\n"
 "    file /sbin/init 0755 0 0 ../init/sbin/init\n"
@@ -169,6 +157,41 @@ const char *help_details =
 "    glob /usr/lib 0777 0 0 -type l -name \"*.so.*\" ./lib\n"
 "\n\n";
 
+const char *sort_details =
+"When using a sort file, the specified paths are within the SquashFS image.\n"
+"Files with lower priority are packed first, default priority is 0.\n"
+"The sorting is stable, files with the same priority do not change place\n"
+"relative to each other.\n"
+"\n"
+"Example:\n"
+"    # Specify a packing order with file globbing\n"
+"    -8000  [glob]          bin/*\n"
+"    -5000  [glob]          lib/*\n"
+"\n"
+"    # glob_no_path means * is allowed to match /\n"
+"    -1000  [glob_no_path]  share/*\n"
+"\n"
+"    # Our boot loader needs this\n"
+"    -100000  [dont_compress,dont_fragment,nosparse]  boot/vmlinuz\n"
+"\n"
+"    # For demonstration, a quoted filename and no flags\n"
+"    1337  \"usr/share/my \\\"special\\\" file  \"\n"
+"\n\n";
+
+static const char *xattr_details =
+"The format of xattr files tries to immitate the format generated\n"
+"by `getfattr --dump`.\n"
+"\n"
+"Example:\n"
+"    # file: dev/\n"
+"    security.selinux=\"system_u:object_r:device_t:s0\"\n"
+"    user.beverage_preference=0xCAFECAFEDECAFBAD\n"
+"\n"
+"    # file: dev/rfkill\n"
+"    security.selinux=\"system_u:object_r:wireless_device_t:s0\"\n"
+"    system.posix_acl_access=0sSGVsbG8gdGhlcmUgOi0pCg==\n"
+"\n\n";
+
 void process_command_line(options_t *opt, int argc, char **argv)
 {
 	bool have_compressor;
@@ -285,10 +308,20 @@ void process_command_line(options_t *opt, int argc, char **argv)
 			opt->selinux = optarg;
 			break;
 #endif
+		case 'A':
+			opt->xattr_file = optarg;
+			break;
+		case 'S':
+			opt->sortfile = optarg;
+			break;
 		case 'h':
-			printf(help_string,
-			       SQFS_DEFAULT_BLOCK_SIZE, SQFS_DEVBLK_SIZE);
-			fputs(help_details, stdout);
+			fputs(help_string, stdout);
+			printf(pack_options, SQFS_DEFAULT_BLOCK_SIZE,
+			       SQFS_DEVBLK_SIZE);
+			fputs(extra_options, stdout);
+			fputs(pack_details, stdout);
+			fputs(sort_details, stdout);
+			fputs(xattr_details, stdout);
 			compressor_print_available();
 			exit(EXIT_SUCCESS);
 		case 'V':
