@@ -8,16 +8,18 @@
 
 static int print_name(const sqfs_tree_node_t *n, bool dont_escape)
 {
-	char *start, *ptr, *name = sqfs_tree_node_get_path(n);
+	char *start, *ptr, *name;
+	int ret;
 
-	if (name == NULL) {
-		perror("Recovering file path of tree node");
+	ret = sqfs_tree_node_get_path(n, &name);
+	if (ret != 0) {
+		sqfs_perror(NULL, "Recovering file path of tree node", ret);
 		return -1;
 	}
 
 	if (canonicalize_name(name) != 0) {
 		fprintf(stderr, "Error sanitizing file path '%s'\n", name);
-		free(name);
+		sqfs_free(name);
 		return -1;
 	}
 
@@ -47,7 +49,7 @@ static int print_name(const sqfs_tree_node_t *n, bool dont_escape)
 		fputc('"', stdout);
 	}
 
-	free(name);
+	sqfs_free(name);
 	return 0;
 }
 
