@@ -24,6 +24,47 @@ static sqfs_hard_link_t *find_hard_link(const char *name, sqfs_u32 inum)
 	return lnk;
 }
 
+static void inode_stat(const sqfs_tree_node_t *node, struct stat *sb)
+{
+	memset(sb, 0, sizeof(*sb));
+
+	sb->st_mode = node->inode->base.mode;
+	sb->st_uid = node->uid;
+	sb->st_gid = node->gid;
+	sb->st_mtime = node->inode->base.mod_time;
+
+	switch (node->inode->base.type) {
+	case SQFS_INODE_BDEV:
+	case SQFS_INODE_CDEV:
+		sb->st_rdev = node->inode->data.dev.devno;
+		break;
+	case SQFS_INODE_EXT_BDEV:
+	case SQFS_INODE_EXT_CDEV:
+		sb->st_rdev = node->inode->data.dev_ext.devno;
+		break;
+	case SQFS_INODE_SLINK:
+		sb->st_size = node->inode->data.slink.target_size;
+		break;
+	case SQFS_INODE_EXT_SLINK:
+		sb->st_size = node->inode->data.slink_ext.target_size;
+		break;
+	case SQFS_INODE_FILE:
+		sb->st_size = node->inode->data.file.file_size;
+		break;
+	case SQFS_INODE_EXT_FILE:
+		sb->st_size = node->inode->data.file_ext.file_size;
+		break;
+	case SQFS_INODE_DIR:
+		sb->st_size = node->inode->data.dir.size;
+		break;
+	case SQFS_INODE_EXT_DIR:
+		sb->st_size = node->inode->data.dir_ext.size;
+		break;
+	default:
+		break;
+	}
+}
+
 static int write_tree_dfs(const sqfs_tree_node_t *n)
 {
 	sqfs_hard_link_t *lnk = NULL;
@@ -61,9 +102,9 @@ static int write_tree_dfs(const sqfs_tree_node_t *n)
 			return 0;
 		}
 
-		name = sqfs_tree_node_get_path(n);
-		if (name == NULL) {
-			perror("resolving tree node path");
+		ret = sqfs_tree_node_get_path(n, &name);
+		if (ret != 0) {
+			sqfs_perror(NULL, "resolving tree node path", ret);
 			return -1;
 		}
 
@@ -78,14 +119,14 @@ static int write_tree_dfs(const sqfs_tree_node_t *n)
 		if (lnk != NULL) {
 			ret = write_hard_link(out_file, &sb, name, lnk->target,
 					      record_counter++);
-			free(name);
+			sqfs_free(name);
 			return ret;
 		}
 	}
 
 	if (!no_xattr) {
 		if (get_xattrs(name, n->inode, &xattr)) {
-			free(name);
+			sqfs_free(name);
 			return -1;
 		}
 	}
@@ -99,24 +140,24 @@ static int write_tree_dfs(const sqfs_tree_node_t *n)
 		goto out_skip;
 
 	if (ret < 0) {
-		free(name);
+		sqfs_free(name);
 		return -1;
 	}
 
 	if (S_ISREG(sb.st_mode)) {
 		if (sqfs_data_reader_dump(name, data, n->inode, out_file,
 					  super.block_size)) {
-			free(name);
+			sqfs_free(name);
 			return -1;
 		}
 
 		if (padd_file(out_file, sb.st_size)) {
-			free(name);
+			sqfs_free(name);
 			return -1;
 		}
 	}
 
-	free(name);
+	sqfs_free(name);
 skip_hdr:
 	for (n = n->children; n != NULL; n = n->next) {
 		if (write_tree_dfs(n))
@@ -131,7 +172,7 @@ out_skip:
 		fprintf(stderr, "Skipping %s\n", name);
 		ret = 0;
 	}
-	free(name);
+	sqfs_free(name);
 	return ret;
 }
 
@@ -141,8 +182,12 @@ int write_tree(const sqfs_tree_node_t *n)
 	int status = -1;
 
 	if (!no_links) {
-		if (sqfs_tree_find_hard_links(n, &links))
+		int ret = sqfs_tree_find_hard_links(n, &links);
+		if (ret) {
+			sqfs_perror(NULL, "detecting hard links in "
+				    "file system tree", ret);
 			return -1;
+		}
 
 		for (lnk = links; lnk != NULL; lnk = lnk->next) {
 			lnk->target = assemble_tar_path(lnk->target, false);
@@ -157,7 +202,7 @@ out_links:
 	while (links != NULL) {
 		lnk = links;
 		links = links->next;
-		free(lnk->target);
+		sqfs_free(lnk->target);
 		free(lnk);
 	}
 	return status;
