@@ -10,7 +10,11 @@
 #include "config.h"
 #include "common.h"
 #include "compat.h"
-#include "tar.h"
+
+#include "util/util.h"
+#include "tar/tar.h"
+#include "tar/format.h"
+#include "io/xfrm.h"
 
 #include <stdlib.h>
 #include <getopt.h>
