@@ -94,6 +94,7 @@ typedef struct sqfs_block_writer_t sqfs_block_writer_t;
 typedef struct sqfs_block_writer_stats_t sqfs_block_writer_stats_t;
 typedef struct sqfs_block_processor_stats_t sqfs_block_processor_stats_t;
 typedef struct sqfs_block_processor_desc_t sqfs_block_processor_desc_t;
+typedef struct sqfs_readdir_state_t sqfs_readdir_state_t;
 
 typedef struct sqfs_fragment_t sqfs_fragment_t;
 typedef struct sqfs_dir_header_t sqfs_dir_header_t;
@@ -133,11 +134,12 @@ typedef struct sqfs_object_t {
  *
  * @memberof sqfs_object_t
  *
- * @param obj A pointer to an object
+ * @param obj A pointer to an object or NULL
  */
 static SQFS_INLINE void sqfs_destroy(void *obj)
 {
-	((sqfs_object_t *)obj)->destroy((sqfs_object_t *)obj);
+	if (obj)
+		((sqfs_object_t *)obj)->destroy((sqfs_object_t *)obj);
 }
 
 /**
