@@ -5,7 +5,8 @@
  * Copyright (C) 2019 David Oberhollenzer <goliath@infraroot.at>
  */
 #include "config.h"
-#include "common.h"
+#include "compress_cli.h"
+#include "compat.h"
 
 #include <stdbool.h>
 #include <stdlib.h>
