@@ -5,7 +5,8 @@
  * Copyright (C) 2019 David Oberhollenzer <goliath@infraroot.at>
  */
 #include "common.h"
-#include "rbtree.h"
+#include "util/rbtree.h"
+#include "util/util.h"
 
 #include <stdlib.h>
 #include <assert.h>
@@ -23,52 +24,44 @@ static int map_nodes(rbtree_t *inumtree, sqfs_hard_link_t **out,
 	/* XXX: refuse to generate hard links to directories */
 	if (n->children != NULL) {
 		for (n = n->children; n != NULL; n = n->next) {
-			if (map_nodes(inumtree, out, n))
-				return -1;
+			ret = map_nodes(inumtree, out, n);
+			if (ret != 0)
+				return ret;
 		}
 		return 0;
 	}
 
 	if (!is_filename_sane((const char *)n->name, false))
-		return 0;
+		return SQFS_ERROR_CORRUPTED;
 
 	idx = n->inode->base.inode_number;
 	tn = rbtree_lookup(inumtree, &idx);
 
-	if (tn == NULL) {
-		ret = rbtree_insert(inumtree, &idx, &n);
-		if (ret != 0)
-			goto fail_insert;
-		return 0;
-	}
+	if (tn == NULL)
+		return rbtree_insert(inumtree, &idx, &n);
 
 	target = *((const sqfs_tree_node_t **)rbtree_node_value(tn));
 
 	lnk = calloc(1, sizeof(*lnk));
 	if (lnk == NULL)
-		goto fail_oom;
+		return SQFS_ERROR_ALLOC;
 
 	lnk->inode_number = idx;
-	lnk->target = sqfs_tree_node_get_path(target);
-	if (lnk->target == NULL)
-		goto fail_oom;
-
-	if (canonicalize_name(lnk->target) == 0) {
-		lnk->next = (*out);
-		(*out) = lnk;
-	} else {
-		free(lnk->target);
+	ret = sqfs_tree_node_get_path(target, &lnk->target);
+	if (ret != 0) {
 		free(lnk);
+		return ret;
 	}
+
+	if (canonicalize_name(lnk->target) != 0) {
+		sqfs_free(lnk->target);
+		free(lnk);
+		return SQFS_ERROR_CORRUPTED;
+	}
+
+	lnk->next = (*out);
+	(*out) = lnk;
 	return 0;
-fail_oom:
-	fputs("detecting hard links in file system tree: out of memory\n",
-	      stderr);
-	free(lnk);
-	return -1;
-fail_insert:
-	sqfs_perror(NULL, "detecting hard links in file system tree", ret);
-	return -1;
 }
 
 static int compare_inum(const void *ctx, const void *lhs, const void *rhs)
@@ -89,11 +82,8 @@ int sqfs_tree_find_hard_links(const sqfs_tree_node_t *root,
 	ret = rbtree_init(&inumtree, sizeof(sqfs_u32),
 			  sizeof(sqfs_tree_node_t *),
 			  compare_inum);
-	if (ret != 0) {
-		sqfs_perror(NULL,
-			    "detecting hard links in file system tree", ret);
-		return -1;
-	}
+	if (ret != 0)
+		return ret;
 
 	ret = map_nodes(&inumtree, out, root);
 	rbtree_cleanup(&inumtree);
@@ -105,8 +95,7 @@ int sqfs_tree_find_hard_links(const sqfs_tree_node_t *root,
 			free(lnk->target);
 			free(lnk);
 		}
-		return -1;
 	}
 
-	return 0;
+	return ret;
 }
