@@ -6,6 +6,7 @@
  */
 #include "config.h"
 
+#include "util/util.h"
 #include "fstree.h"
 
 #include <string.h>
@@ -62,7 +63,7 @@ int fstree_resolve_hard_link(fstree_t *fs, tree_node_t *node)
 		return -1;
 	}
 
-	if (node->link_count == 0x0FFFF) {
+	if (node->link_count == 0xFFFFFFFF) {
 		errno = EMLINK;
 		return -1;
 	}
