@@ -18,10 +18,10 @@
 #include "sqfs/block.h"
 #include "sqfs/io.h"
 
-#include "str_table.h"
-#include "rbtree.h"
-#include "array.h"
-#include "util.h"
+#include "util/str_table.h"
+#include "util/rbtree.h"
+#include "util/array.h"
+#include "util/util.h"
 
 #include <stdlib.h>
 #include <string.h>
