@@ -5,19 +5,18 @@
  * Copyright (C) 2019 David Oberhollenzer <goliath@infraroot.at>
  */
 #include "config.h"
-
 #include "util/util.h"
 
 static void normalize_slashes(char *filename)
 {
 	char *dst = filename, *src = filename;
 
-	while (*src == '/' || *src == '\\')
+	while (*src == '/')
 		++src;
 
 	while (*src != '\0') {
-		if (*src == '/' || *src == '\\') {
-			while (*src == '/' || *src == '\\')
+		if (*src == '/') {
+			while (*src == '/')
 				++src;
 			if (*src == '\0')
 				break;
