@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2021 David Oberhollenzer <goliath@infraroot.at>
  */
-#include "mempool.h"
+#include "util/mempool.h"
 
 #include <stdlib.h>
 #include <limits.h>
@@ -212,4 +212,5 @@ void mem_pool_free(mem_pool_t *mem, void *ptr)
 	assert((it->bitmap[i] & (1 << j)) != 0);
 
 	it->bitmap[i] &= ~(1 << j);
+	it->obj_free += 1;
 }
