@@ -5,8 +5,9 @@
  * Copyright (C) 2019 David Oberhollenzer <goliath@infraroot.at>
  */
 #include "config.h"
-#include "tar.h"
-#include "../test.h"
+#include "tar/tar.h"
+#include "io/file.h"
+#include "util/test.h"
 
 int main(int argc, char **argv)
 {
@@ -17,11 +18,10 @@ int main(int argc, char **argv)
 	fp = istream_open_file(STRVALUE(TESTPATH) "/" STRVALUE(TESTFILE));
 	TEST_NOT_NULL(fp);
 	TEST_ASSERT(read_header(fp, &hdr) == 0);
-	TEST_EQUAL_UI(hdr.sb.st_mode, S_IFREG | 0644);
-	TEST_EQUAL_UI(hdr.sb.st_uid, 01750);
-	TEST_EQUAL_UI(hdr.sb.st_gid, 01750);
-	TEST_EQUAL_UI(hdr.sb.st_size, 8589934592);
-	TEST_EQUAL_UI(hdr.sb.st_mtime, 1542959190);
+	TEST_EQUAL_UI(hdr.mode, S_IFREG | 0644);
+	TEST_EQUAL_UI(hdr.uid, 01750);
+	TEST_EQUAL_UI(hdr.gid, 01750);
+	TEST_EQUAL_UI(hdr.actual_size, 8589934592);
 	TEST_EQUAL_UI(hdr.mtime, 1542959190);
 	TEST_STR_EQUAL(hdr.name, "big-file.bin");
 	TEST_ASSERT(!hdr.unknown_record);
